sluyspy package
===============

Submodules
----------

.. toctree::
   :maxdepth: 4

   sluyspy.air_visual
   sluyspy.cli
   sluyspy.env
   sluyspy.fit
   sluyspy.html
   sluyspy.numerics
   sluyspy.plot
   sluyspy.solar_energy
   sluyspy.solar_panels
   sluyspy.system
   sluyspy.text
   sluyspy.weather
   sluyspy.wp_data

Module contents
---------------

.. automodule:: sluyspy
   :members:
   :undoc-members:
   :show-inheritance:
